Project description
===================

Dioscuri provides classes and methods for working with Gemini WorkList (gwl) files.

A Gemini worklist file is a text file that contains pipetting instructions for the Tecan Freedom EVO robots. Dioscuri uses the Freedom EVOware software's specification of the gwl format.


**Install:**

.. code:: bash

  pip install dioscuri

**Web documentation:** `<https://edinburgh-genome-foundry.github.io/Dioscuri/>`_

**Github page:** `<https://github.com/Edinburgh-Genome-Foundry/Dioscuri>`_


**License:** MIT

Copyright 2020 Edinburgh Genome Foundry, University of Edinburgh


More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Dioscuri is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
